@@ -2,14 +2,17 @@ import copy
 import numpy as np
 import pickle
 from typing import List, Optional, Type, Union
+import warnings
 
 from autoconf import conf
-from autoarray.structures.abstract_structure import AbstractStructure
-from autoarray.structures.arrays.one_d.array_1d import Array1D
-from autoarray.structures.arrays.two_d.array_2d import Array2D
-from autoarray.structures.grids.one_d.grid_1d import Grid1D
-from autoarray.structures.grids.two_d.grid_2d import Grid2D
-from autoarray.structures.grids.two_d.grid_2d_iterate import Grid2DIterate
+from autoarray.structures.arrays.uniform_1d import Array1D
+from autoarray.structures.arrays.uniform_2d import Array2D
+from autoarray.structures.grids.uniform_1d import Grid1D
+from autoarray.structures.grids.uniform_2d import Grid2D
+from autoarray.structures.grids.iterate_2d import Grid2DIterate
+from autoarray.structures.vectors.uniform import VectorYX2D
+from autoarray.structures.visibilities import Visibilities
+from autoarray.structures.visibilities import VisibilitiesNoiseMap
 from autoarray.mask.mask_1d import Mask1D
 from autoarray.mask.mask_2d import Mask2D
 
@@ -18,7 +21,23 @@ from autoarray import exc
 
 class AbstractWTilde:
     def __init__(self, curvature_preload, noise_map_value):
+        """
+        Packages together all derived data quantities necessary to fit `data (e.g. `Imaging`, Interferometer`) using
+        an ` Inversion` via the w_tilde formalism.
 
+        The w_tilde formalism performs linear algebra formalism in a way that speeds up the construction of the
+        simultaneous linear equations by bypassing the construction of a `mapping_matrix` and precomputing
+        operations like blurring or a Fourier transform.
+
+        Parameters
+        ----------
+        curvature_preload
+            A matrix which uses the imaging's noise-map and PSF to preload as much of the computation of the
+            curvature matrix as possible.
+        noise_map_value
+            The first value of the noise-map used to construct the curvature preload, which is used as a sanity
+            check when performing the inversion to ensure the preload corresponds to the data being fitted.
+        """
         self.curvature_preload = curvature_preload
         self.noise_map_value = noise_map_value
 
@@ -31,7 +50,7 @@ class AbstractWTilde:
                 ""
                 f"The value of the noise map is {noise_map[0]} whereas in WTildeImaging it is {self.noise_map_value}"
                 ""
-                "Update WTildeImaging or do not use the w_tilde formalism to perform the LinearEqn."
+                "Update WTildeImaging or do not use the w_tilde formalism to perform the LEq."
             )
 
 
@@ -39,8 +58,9 @@ def grid_via_grid_class_from(
     mask: Union[Mask1D, Mask2D],
     grid_class: Union[Type[Grid1D], Type[Grid2D]],
     fractional_accuracy: float,
+    relative_accuracy: Optional[float],
     sub_steps: List[int],
-) -> Optional[Union[Grid1D, Grid2D]]:
+) -> Optional[Union[Grid1D, Grid2D, Grid2DIterate]]:
 
     if mask.pixel_scales is None:
         return None
@@ -62,7 +82,10 @@ def grid_via_grid_class_from(
     elif grid_class is Grid2DIterate:
 
         return Grid2DIterate.from_mask(
-            mask=mask, fractional_accuracy=fractional_accuracy, sub_steps=sub_steps
+            mask=mask,
+            fractional_accuracy=fractional_accuracy,
+            relative_accuracy=relative_accuracy,
+            sub_steps=sub_steps,
         )
 
 
@@ -70,10 +93,11 @@ class AbstractSettingsDataset:
     def __init__(
         self,
         grid_class: Optional[Union[Type[Grid1D], Type[Grid2D]]] = None,
-        grid_inversion_class: Optional[Union[Type[Grid1D], Type[Grid2D]]] = None,
+        grid_pixelized_class: Optional[Union[Type[Grid1D], Type[Grid2D]]] = None,
         sub_size: int = 2,
-        sub_size_inversion: int = 2,
+        sub_size_pixelized: int = 2,
         fractional_accuracy: float = 0.9999,
+        relative_accuracy: Optional[float] = None,
         sub_steps: Optional[List[int]] = None,
         signal_to_noise_limit: Optional[float] = None,
         signal_to_noise_limit_radii: Optional[float] = None,
@@ -90,17 +114,22 @@ class AbstractSettingsDataset:
         grid_class : ag.Grid2D
             The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid2D` and
             `Grid2DIterate` (see the `Grid2D` documentation for a description of these options).
-        grid_inversion_class : ag.Grid2D
-            The type of grid used to create the grid that maps the `LinearEqn` source pixels to the data's image-pixels.
+        grid_pixelized_class : ag.Grid2D
+            The type of grid used to create the grid that maps the `LEq` source pixels to the data's image-pixels.
             The options are `Grid2D` and `Grid2DIterate` (see the `Grid2D` documentation for a
             description of these options).
         sub_size
-            If the grid and / or grid_inversion use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
+            If the grid and / or grid_pixelized use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
         fractional_accuracy
-            If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the fractional accuracy it
-            uses when evaluating functions.
+            If the grid and / or grid_pixelized use a `Grid2DIterate`, this sets the fractional accuracy it
+            uses when evaluating functions, where the fraction accuracy is the ratio of the values computed using
+            two grids at a higher and lower sub-grid size.
+        relative_accuracy
+            If the grid and / or grid_pixelized use a `Grid2DIterate`, this sets the relative accuracy it
+            uses when evaluating functions, where the relative accuracy is the absolute difference of the values
+            computed using two grids at a higher and lower sub-grid size.
         sub_steps : [int]
-            If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the steps the sub-size is increased by
+            If the grid and / or grid_pixelized use a `Grid2DIterate`, this sets the steps the sub-size is increased by
             to meet the fractional accuracy when evaluating functions.
         signal_to_noise_limit
             If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
@@ -108,10 +137,11 @@ class AbstractSettingsDataset:
         """
 
         self.grid_class = grid_class
-        self.grid_inversion_class = grid_inversion_class
+        self.grid_pixelized_class = grid_pixelized_class
         self.sub_size = sub_size
-        self.sub_size_inversion = sub_size_inversion
+        self.sub_size_pixelized = sub_size_pixelized
         self.fractional_accuracy = fractional_accuracy
+        self.relative_accuracy = relative_accuracy
 
         if sub_steps is None:
             sub_steps = [2, 4, 8, 16]
@@ -126,15 +156,17 @@ class AbstractSettingsDataset:
             mask=mask,
             grid_class=self.grid_class,
             fractional_accuracy=self.fractional_accuracy,
+            relative_accuracy=self.relative_accuracy,
             sub_steps=self.sub_steps,
         )
 
-    def grid_inversion_from(self, mask) -> Union[Grid1D, Grid2D]:
+    def grid_pixelized_from(self, mask) -> Union[Grid1D, Grid2D]:
 
         return grid_via_grid_class_from(
             mask=mask,
-            grid_class=self.grid_inversion_class,
+            grid_class=self.grid_pixelized_class,
             fractional_accuracy=self.fractional_accuracy,
+            relative_accuracy=self.relative_accuracy,
             sub_steps=self.sub_steps,
         )
 
@@ -142,8 +174,8 @@ class AbstractSettingsDataset:
 class AbstractDataset:
     def __init__(
         self,
-        data: AbstractStructure,
-        noise_map: AbstractStructure,
+        data: Union[Array1D, Array2D, VectorYX2D, Visibilities],
+        noise_map: Union[Array1D, Array2D, VectorYX2D, VisibilitiesNoiseMap],
         settings=AbstractSettingsDataset(),
         name: str = None,
     ):
@@ -152,9 +184,9 @@ class AbstractDataset:
 
         Parameters
         ----------
-        data : AbstractStructure
+        dataucture
             The array of the image data, in units of electrons per second.
-        noise_map : AbstractStructure
+        noise_mapucture
             An array describing the RMS standard deviation error in each pixel, preferably in units of electrons per
             second.
         """
@@ -189,7 +221,10 @@ class AbstractDataset:
                 self.noise_map.native,
             )
 
-            noise_map = noise_map._new_structure(noise_map_limit, mask=mask).slim
+            if len(self.noise_map.native) == 1:
+                noise_map = Array1D.manual_mask(array=noise_map_limit, mask=mask)
+            else:
+                noise_map = Array2D.manual_mask(noise_map_limit, mask=mask)
 
         self.noise_map = noise_map
 
@@ -201,10 +236,22 @@ class AbstractDataset:
             self.grid = settings.grid_from(mask=mask_grid)
 
             mask_inversion = mask.mask_new_sub_size_from(
-                mask=mask, sub_size=settings.sub_size_inversion
+                mask=mask, sub_size=settings.sub_size_pixelized
             )
 
-            self.grid_inversion = settings.grid_inversion_from(mask=mask_inversion)
+            self.grid_pixelized = settings.grid_pixelized_from(mask=mask_inversion)
+
+    @property
+    def shape_native(self):
+        return self.mask.shape_native
+
+    @property
+    def shape_slim(self):
+        return self.data.shape_slim
+
+    @property
+    def pixel_scales(self):
+        return self.mask.pixel_scales
 
     @property
     def mask(self) -> Union[Mask1D, Mask2D]:
@@ -239,7 +286,12 @@ class AbstractDataset:
     def signal_to_noise_map(self) -> Union[Array1D, Array2D]:
         """
         The estimated signal-to-noise_maps mappers of the image.
+
+        Warnings airse when masked native noise-maps are used, whose masked entries are given values of 0.0. We
+        uses the warnings module to surpress these RunTimeWarnings.
         """
+        warnings.filterwarnings("ignore")
+
         signal_to_noise_map = np.divide(self.data, self.noise_map)
         signal_to_noise_map[signal_to_noise_map < 0] = 0
         return signal_to_noise_map
@@ -256,9 +308,7 @@ class AbstractDataset:
         """
         The estimated absolute_signal-to-noise_maps mappers of the image.
         """
-        return self.data._new_structure(
-            np.divide(np.abs(self.data), self.noise_map), mask=self.data.mask
-        )
+        return np.divide(np.abs(self.data), self.noise_map)
 
     @property
     def absolute_signal_to_noise_max(self) -> float:
@@ -273,9 +323,7 @@ class AbstractDataset:
         The potential chi-squared-map of the imaging data_type. This represents how much each pixel can contribute to
         the chi-squared-map, assuming the model fails to fit it at all (e.g. model value = 0.0).
         """
-        return self.data._new_structure(
-            np.square(self.absolute_signal_to_noise_map), mask=self.data.mask
-        )
+        return np.square(self.absolute_signal_to_noise_map)
 
     @property
     def potential_chi_squared_max(self) -> float:
