@@ -8,22 +8,50 @@ from autoconf import cached_property
 from autoarray.dataset.abstract_dataset import AbstractWTilde
 from autoarray.dataset.abstract_dataset import AbstractSettingsDataset
 from autoarray.dataset.abstract_dataset import AbstractDataset
-from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.structures.arrays.uniform_2d import Array2D
 from autoarray.operators.convolver import Convolver
-from autoarray.structures.grids.two_d.grid_2d import Grid2D
-from autoarray.structures.kernel_2d import Kernel2D
+from autoarray.structures.grids.uniform_2d import Grid2D
+from autoarray.structures.arrays.kernel_2d import Kernel2D
 from autoarray.mask.mask_2d import Mask2D
 
 from autoarray import exc
-from autoarray.inversion.linear_eqn import linear_eqn_util
+from autoarray.inversion.linear_eqn import leq_util
 from autoarray.dataset import preprocess
 
 logger = logging.getLogger(__name__)
 
 
 class WTildeImaging(AbstractWTilde):
-    def __init__(self, curvature_preload, indexes, lengths, noise_map_value):
+    def __init__(
+        self,
+        curvature_preload: np.ndarray,
+        indexes: np.ndim,
+        lengths: np.ndarray,
+        noise_map_value: float,
+    ):
+        """
+        Packages together all derived data quantities necessary to fit `Imaging` data using an ` Inversion` via the
+        w_tilde formalism.
 
+        The w_tilde formalism performs linear algebra formalism in a way that speeds up the construction of the
+        simultaneous linear equations by bypassing the construction of a `mapping_matrix` and precomputing the
+        blurring operations performed using the imaging's PSF.
+
+        Parameters
+        ----------
+        curvature_preload
+            A matrix which uses the imaging's noise-map and PSF to preload as much of the computation of the
+            curvature matrix as possible.
+        indexes
+            The image-pixel indexes of the curvature preload matrix, which are used to compute the curvature matrix
+            efficiently when performing an inversion.
+        lengths
+            The lengths of how many indexes each curvature preload contains, again used to compute the curvature
+            matrix efficienctly.
+        noise_map_value
+            The first value of the noise-map used to construct the curvature preload, which is used as a sanity
+            check when performing the inversion to ensure the preload corresponds to the data being fitted.
+        """
         super().__init__(
             curvature_preload=curvature_preload, noise_map_value=noise_map_value
         )
@@ -36,10 +64,11 @@ class SettingsImaging(AbstractSettingsDataset):
     def __init__(
         self,
         grid_class=Grid2D,
-        grid_inversion_class=Grid2D,
+        grid_pixelized_class=Grid2D,
         sub_size: int = 1,
-        sub_size_inversion=4,
+        sub_size_pixelized=4,
         fractional_accuracy: float = 0.9999,
+        relative_accuracy: Optional[float] = None,
         sub_steps: List[int] = None,
         signal_to_noise_limit: Optional[float] = None,
         signal_to_noise_limit_radii: Optional[float] = None,
@@ -57,17 +86,22 @@ class SettingsImaging(AbstractSettingsDataset):
         grid_class : ag.Grid2D
             The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid2D`,
             and `Grid2DIterate` (see the `Grid2D` documentation for a description of these options).
-        grid_inversion_class : ag.Grid2D
-            The type of grid used to create the grid that maps the `LinearEqn` source pixels to the data's image-pixels.
+        grid_pixelized_class : ag.Grid2D
+            The type of grid used to create the grid that maps the `LEq` source pixels to the data's image-pixels.
             The options are `Grid2D` and `Grid2DIterate`.
             (see the `Grid2D` documentation for a description of these options).
         sub_size
-            If the grid and / or grid_inversion use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
+            If the grid and / or grid_pixelized use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
         fractional_accuracy
-            If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the fractional accuracy it
-            uses when evaluating functions.
+            If the grid and / or grid_pixelized use a `Grid2DIterate`, this sets the fractional accuracy it
+            uses when evaluating functions, where the fraction accuracy is the ratio of the values computed using
+            two grids at a higher and lower sub-grid size.
+        relative_accuracy
+            If the grid and / or grid_pixelized use a `Grid2DIterate`, this sets the relative accuracy it
+            uses when evaluating functions, where the relative accuracy is the absolute difference of the values
+            computed using two grids at a higher and lower sub-grid size.
         sub_steps : [int]
-            If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the steps the sub-size is increased by
+            If the grid and / or grid_pixelized use a `Grid2DIterate`, this sets the steps the sub-size is increased by
             to meet the fractional accuracy when evaluating functions.
         signal_to_noise_limit
             If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
@@ -79,10 +113,11 @@ class SettingsImaging(AbstractSettingsDataset):
 
         super().__init__(
             grid_class=grid_class,
-            grid_inversion_class=grid_inversion_class,
+            grid_pixelized_class=grid_pixelized_class,
             sub_size=sub_size,
-            sub_size_inversion=sub_size_inversion,
+            sub_size_pixelized=sub_size_pixelized,
             fractional_accuracy=fractional_accuracy,
+            relative_accuracy=relative_accuracy,
             sub_steps=sub_steps,
             signal_to_noise_limit=signal_to_noise_limit,
             signal_to_noise_limit_radii=signal_to_noise_limit_radii,
@@ -108,12 +143,12 @@ class Imaging(AbstractDataset):
         ----------
         image
             The array of the image data, in units of electrons per second.
-        noise_map : Array2D
+        noise_map
             An array describing the RMS standard deviation error in each pixel in units of electrons per second.
         psf
             An array describing the Point Spread Function kernel of the image.
-        mask:Mask2D
-            The 2D mask that is applied to the image.
+        settings
+            Controls settings of how the dataset is set up (e.g. the types of grids used to perform calculations).
         """
 
         self.unmasked = None
@@ -157,7 +192,7 @@ class Imaging(AbstractDataset):
         return self.psf_unormalized
 
     @cached_property
-    def blurring_grid(self):
+    def blurring_grid(self) -> Grid2D:
         """
         Returns a blurring-grid from a mask and the 2D shape of the PSF kernel.
 
@@ -216,7 +251,7 @@ class Imaging(AbstractDataset):
 
         logger.info("IMAGING - Computing W-Tilde... May take a moment.")
 
-        curvature_preload, indexes, lengths = linear_eqn_util.w_tilde_curvature_preload_imaging_from(
+        curvature_preload, indexes, lengths = leq_util.w_tilde_curvature_preload_imaging_from(
             noise_map_native=self.noise_map.native,
             kernel_native=self.psf.native,
             native_index_for_slim_index=self.mask.native_index_for_slim_index,
@@ -252,17 +287,17 @@ class Imaging(AbstractDataset):
         ----------
         noise_map_non_constant
         name
-        image_path : str
+        image_path
             The path to the image .fits file containing the image (e.g. '/path/to/image.fits')
         pixel_scales
             The size of each pixel in scaled units.
         image_hdu
             The hdu the image is contained in the .fits file specified by *image_path*.
-        psf_path : str
+        psf_path
             The path to the psf .fits file containing the psf (e.g. '/path/to/psf.fits')
         psf_hdu
             The hdu the psf is contained in the .fits file specified by *psf_path*.
-        noise_map_path : str
+        noise_map_path
             The path to the noise_map .fits file containing the noise_map (e.g. '/path/to/noise_map.fits')
         noise_map_hdu
             The hdu the noise_map is contained in the .fits file specified by *noise_map_path*.
@@ -291,8 +326,19 @@ class Imaging(AbstractDataset):
 
         return Imaging(image=image, noise_map=noise_map, psf=psf, name=name)
 
-    def apply_mask(self, mask):
+    def apply_mask(self, mask: Mask2D) -> "Imaging":
+        """
+        Apply a mask to the imaging dataset, whereby the mask is applied to the image data and noise-map one-by-one.
 
+        The original unmasked imaging data is stored as the `self.unmasked` attribute. This is used to ensure that if
+        the `apply_mask` function is called multiple times, every mask is always applied to the original unmasked
+        imaging dataset.
+
+        Parameters
+        ----------
+        mask
+            The 2D mask that is applied to the image.
+        """
         if self.image.mask.is_all_false:
             unmasked_imaging = self
         else:
@@ -323,8 +369,18 @@ class Imaging(AbstractDataset):
 
         return imaging
 
-    def apply_settings(self, settings):
+    def apply_settings(self, settings: SettingsImaging) -> "Imaging":
+        """
+        Returns a new instance of the imaging with the input `SettingsImaging` applied to them.
 
+        This can be used to update settings like the types of grids associated with the dataset that are used
+        to perform calculations or putting a limit of the dataset's signal-to-noise.
+
+        Parameters
+        ----------
+        settings
+            The settings for the imaging data that control things like the grids used for calculations.
+        """
         return Imaging(
             image=self.image,
             noise_map=self.noise_map,
@@ -403,12 +459,12 @@ class AbstractSimulatorImaging:
             The exposure time of the simulated imaging.
         background_sky_level
             The level of the background sky of the simulated imaging.
-        normalize_psf : bool
+        normalize_psf
             If `True`, the PSF kernel is normalized so all values sum to 1.0.
         read_noise
             The level of read-noise added to the simulated imaging by drawing from a Gaussian distribution with
             sigma equal to the value `read_noise`.
-        add_poisson_noise : bool
+        add_poisson_noise
             Whether Poisson noise corresponding to photon count statistics on the imaging observation is added.
         noise_if_add_noise_false
             If noise is not added to the simulated dataset a `noise_map` must still be returned. This value gives
@@ -440,7 +496,7 @@ class SimulatorImaging(AbstractSimulatorImaging):
 
         Parameters
         ----------
-        image : Array2D
+        image
             The image before simulating which has noise added, PSF convolution, etc performed to it.
         """
 
