@@ -3,29 +3,76 @@ import numpy as np
 import copy
 from typing import List, Optional
 
+from autoconf import cached_property
+
+from autoarray.dataset.abstract_dataset import AbstractWTilde
 from autoarray.dataset.abstract_dataset import AbstractSettingsDataset
 from autoarray.dataset.abstract_dataset import AbstractDataset
-from autoarray.structures.grids.two_d.grid_2d import Grid2D
+from autoarray.mask.mask_2d import Mask2D
+from autoarray.structures.grids.uniform_2d import Grid2D
 from autoarray.operators.transformer import TransformerDFT
 from autoarray.operators.transformer import TransformerNUFFT
 from autoarray.structures.visibilities import Visibilities
 from autoarray.structures.visibilities import VisibilitiesNoiseMap
 
 from autoarray import exc
-from autoarray.structures.arrays.two_d import array_2d_util
+from autoarray.structures.arrays import array_2d_util
 from autoarray.dataset import preprocess
 
-
 logger = logging.getLogger(__name__)
 
 
+class WTildeInterferometer(AbstractWTilde):
+    def __init__(
+        self,
+        w_matrix: np.ndarray,
+        curvature_preload: np.ndarray,
+        dirty_image: np.ndarray,
+        real_space_mask: Mask2D,
+        noise_map_value: float,
+    ):
+        """
+        Packages together all derived data quantities necessary to fit `Interferometer` data using an ` Inversion` via
+        the w_tilde formalism.
+
+        The w_tilde formalism performs linear algebra formalism in a way that speeds up the construction of  the
+        simultaneous linear equations by bypassing the construction of a `mapping_matrix` and precomputing the
+        Fourier transform operations performed using the interferometer's `uv_wavelengths`.
+
+        Parameters
+        ----------
+        w_matrix
+            The w_tilde matrix used to construct the data vector during an inversion.
+        curvature_preload
+            A matrix which uses the interferometer `uv_wavelengths` to preload as much of the computation of the
+            curvature matrix as possible.
+        dirty_image
+            The real-space image of the visibilities computed via the transform, which is used to construct the
+            curvature matrix.
+        real_space_mask
+            The 2D mask in real-space defining the area where the interferometer data's visibilities are observing
+            a signal.
+        noise_map_value
+            The first value of the noise-map used to construct the curvature preload, which is used as a sanity
+            check when performing the inversion to ensure the preload corresponds to the data being fitted.
+        """
+        super().__init__(
+            curvature_preload=curvature_preload, noise_map_value=noise_map_value
+        )
+
+        self.dirty_image = dirty_image
+        self.real_space_mask = real_space_mask
+
+        self.w_matrix = w_matrix
+
+
 class SettingsInterferometer(AbstractSettingsDataset):
     def __init__(
         self,
         grid_class=Grid2D,
-        grid_inversion_class=Grid2D,
+        grid_pixelized_class=Grid2D,
         sub_size: int = 1,
-        sub_size_inversion=1,
+        sub_size_pixelized=1,
         fractional_accuracy: float = 0.9999,
         sub_steps: List[int] = None,
         signal_to_noise_limit: Optional[float] = None,
@@ -43,17 +90,17 @@ class SettingsInterferometer(AbstractSettingsDataset):
         grid_class : ag.Grid2D
             The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid2D`,
             and `Grid2DIterate` (see the `Grid2D` documentation for a description of these options).
-        grid_inversion_class : ag.Grid2D
-            The type of grid used to create the grid that maps the `LinearEqn` source pixels to the data's image-pixels.
+        grid_pixelized_class : ag.Grid2D
+            The type of grid used to create the grid that maps the `LEq` source pixels to the data's image-pixels.
             The options are `Grid2D` and `Grid2DIterate` (see the `Grid2D` documentation for a
             description of these options).
         sub_size
-            If the grid and / or grid_inversion use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
+            If the grid and / or grid_pixelized use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
         fractional_accuracy
-            If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the fractional accuracy it
+            If the grid and / or grid_pixelized use a `Grid2DIterate`, this sets the fractional accuracy it
             uses when evaluating functions.
         sub_steps : [int]
-            If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the steps the sub-size is increased by
+            If the grid and / or grid_pixelized use a `Grid2DIterate`, this sets the steps the sub-size is increased by
             to meet the fractional accuracy when evaluating functions.
         signal_to_noise_limit
             If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
@@ -62,9 +109,9 @@ class SettingsInterferometer(AbstractSettingsDataset):
 
         super().__init__(
             grid_class=grid_class,
-            grid_inversion_class=grid_inversion_class,
+            grid_pixelized_class=grid_pixelized_class,
             sub_size=sub_size,
-            sub_size_inversion=sub_size_inversion,
+            sub_size_pixelized=sub_size_pixelized,
             fractional_accuracy=fractional_accuracy,
             sub_steps=sub_steps,
             signal_to_noise_limit=signal_to_noise_limit,
@@ -76,9 +123,9 @@ class SettingsInterferometer(AbstractSettingsDataset):
 class Interferometer(AbstractDataset):
     def __init__(
         self,
-        visibilities,
-        noise_map,
-        uv_wavelengths,
+        visibilities: Visibilities,
+        noise_map: VisibilitiesNoiseMap,
+        uv_wavelengths: np.ndarray,
         real_space_mask,
         settings=SettingsInterferometer(),
         name=None,
@@ -149,6 +196,54 @@ class Interferometer(AbstractDataset):
             name=self.name,
         )
 
+    @cached_property
+    def w_tilde(self):
+        """
+        The w_tilde formalism of the linear algebra equations precomputes the Fourier Transform of all the visibilities
+        given the `uv_wavelengths` (see `inversion.inversion_util`).
+
+        The `WTilde` object stores these precomputed values in the interferometer dataset ensuring they are only
+        computed once per analysis.
+
+        This uses lazy allocation such that the calculation is only performed when the wtilde matrices are used,
+        ensuring efficient set up of the `Interferometer` class.
+
+        Returns
+        -------
+        WTildeInterferometer
+            Precomputed values used for the w tilde formalism of linear algebra calculations.
+        """
+
+        from autoarray.inversion.inversion import inversion_util_secret
+
+        logger.info("INTERFEROMETER - Computing W-Tilde... May take a moment.")
+
+        curvature_preload = inversion_util_secret.w_tilde_curvature_preload_interferometer_from(
+            noise_map_real=self.noise_map.real,
+            uv_wavelengths=self.uv_wavelengths,
+            shape_masked_pixels_2d=self.transformer.grid.mask.shape_native_masked_pixels,
+            grid_radians_2d=self.transformer.grid.mask.unmasked_grid_sub_1.in_radians.native,
+        )
+
+        w_matrix = inversion_util_secret.w_tilde_via_preload_from(
+            w_tilde_preload=curvature_preload,
+            native_index_for_slim_index=self.real_space_mask.native_index_for_slim_index,
+        )
+
+        dirty_image = self.transformer.image_from(
+            visibilities=self.visibilities.real * self.noise_map.real ** -2.0
+            + 1j * self.visibilities.imag * self.noise_map.imag ** -2.0,
+            use_adjoint_scaling=True,
+        )
+
+        return WTildeInterferometer(
+            w_matrix=w_matrix,
+            curvature_preload=curvature_preload,
+            dirty_image=dirty_image,
+            real_space_mask=self.real_space_mask,
+            noise_map_value=self.noise_map[0],
+        )
+
     @property
     def mask(self):
         return self.real_space_mask
@@ -201,6 +296,14 @@ class Interferometer(AbstractDataset):
 
         return signal_to_noise_map_real + 1j * signal_to_noise_map_imag
 
+    @property
+    def blurring_grid(self):
+        return None
+
+    @property
+    def convolver(self):
+        return None
+
     def signal_to_noise_limited_from(self, signal_to_noise_limit, mask=None):
 
         interferometer = copy.deepcopy(self)
@@ -289,7 +392,7 @@ class AbstractSimulatorInterferometer:
         name
         real_space_image
             The image before simulating (e.g. the lens and source galaxies before optics blurring and UVPlane read-out).
-        real_space_pixel_scales: float
+        real_space_pixel_scales
             The scale of each pixel in scaled units
         exposure_time_map
             An array representing the effective exposure time of each pixel.
