@@ -6,13 +6,13 @@ import os
 from os import path
 import shutil
 
-from autoarray.structures.arrays.abstract_array import Header
-from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.structures.header import Header
+from autoarray.structures.arrays.uniform_2d import Array2D
 from autoarray.layout.layout import Layout2D
 from autoarray.layout.region import Region2D
 
 from autoarray import exc
-from autoarray.structures.arrays.two_d import array_2d_util
+from autoarray.structures.arrays import array_2d_util
 from autoarray.layout import layout_util
 
 logging.basicConfig()
@@ -27,13 +27,13 @@ def fits_hdu_via_quadrant_letter_from(quadrant_letter):
     elif quadrant_letter == "B" or quadrant_letter == "A":
         return 4
     else:
-        raise exc.FrameException("Quadrant letter for FrameACS must be A, B, C or D.")
+        raise exc.ArrayException("Quadrant letter for FrameACS must be A, B, C or D.")
 
 
 def array_eps_to_counts(array_eps, bscale, bzero):
 
     if bscale is None:
-        raise exc.FrameException(
+        raise exc.ArrayException(
             "Cannot convert a Frame2D to units COUNTS without a bscale attribute (bscale = None)."
         )
 
@@ -137,7 +137,7 @@ class Array2DACS(Array2D):
                 bias = bias[0:2068, 2072:4144]
 
         else:
-            raise exc.FrameException(
+            raise exc.ArrayException(
                 "Quadrant letter for FrameACS must be A, B, C or D."
             )
 
@@ -331,7 +331,7 @@ class Array2DACS(Array2D):
 
         Parameters
         ----------
-        file_path : str
+        file_path
             The path the file is output to, including the filename and the ``.fits`` extension,
             e.g. '/path/to/filename.fits'
         """
