@@ -1,14 +1,17 @@
+from abc import ABC
 import logging
-
 import numpy as np
 
+from autoarray.abstract_ndarray import AbstractNDArray
+
 from autoarray import exc
+from autoarray import type as ty
 
 logging.basicConfig()
 logger = logging.getLogger(__name__)
 
 
-class AbstractMask(np.ndarray):
+class Mask(AbstractNDArray, ABC):
 
     pixel_scales = None
 
@@ -17,7 +20,7 @@ class AbstractMask(np.ndarray):
         cls,
         mask: np.ndarray,
         origin: tuple,
-        pixel_scales: tuple,
+        pixel_scales: ty.PixelScales,
         sub_size: int = 1,
         *args,
         **kwargs
@@ -54,7 +57,7 @@ class AbstractMask(np.ndarray):
 
     def __array_finalize__(self, obj):
 
-        if isinstance(obj, AbstractMask):
+        if isinstance(obj, Mask):
             self.sub_size = obj.sub_size
             self.pixel_scales = obj.pixel_scales
             self.origin = obj.origin
@@ -62,30 +65,8 @@ class AbstractMask(np.ndarray):
             self.sub_size = 1
             self.pixel_scales = None
 
-    def __reduce__(self):
-
-        # Get the parent's __reduce__ tuple
-        pickled_state = super().__reduce__()
-
-        # Create our own tuple to pass to __setstate__
-
-        class_dict = {}
-        for key, value in self.__dict__.items():
-            class_dict[key] = value
-        new_state = pickled_state[2] + (class_dict,)
-
-        # Return a tuple that replaces the parent's __setstate__ tuple with our own
-        return pickled_state[0], pickled_state[1], new_state
-
-    # noinspection PyMethodOverriding
-    def __setstate__(self, state):
-
-        for key, value in state[-1].items():
-            setattr(self, key, value)
-        super().__setstate__(state[0:-1])
-
     @property
-    def pixel_scale(self):
+    def pixel_scale(self) -> float:
         """
         For a mask with dimensions two or above check that are pixel scales are the same, and if so return this
         single value as a float.
@@ -100,7 +81,7 @@ class AbstractMask(np.ndarray):
         return self.pixel_scales[0]
 
     @property
-    def dimensions(self):
+    def dimensions(self) -> int:
         return len(self.shape)
 
     @property
@@ -122,7 +103,9 @@ class AbstractMask(np.ndarray):
         return 1.0 / self.sub_length
 
     def output_to_fits(self, file_path: str, overwrite: bool = False):
-        raise NotImplementedError()
+        """
+        Overwrite with method to output the mask to a `.fits` file.
+        """
 
     @property
     def pixels_in_mask(self) -> int:
@@ -166,7 +149,7 @@ class AbstractMask(np.ndarray):
         """
         return int(self.pixels_in_mask * self.sub_size ** self.dimensions)
 
-    def mask_new_sub_size_from(self, mask, sub_size=1) -> "AbstractMask":
+    def mask_new_sub_size_from(self, mask, sub_size=1) -> "Mask":
         """
         Returns the mask on the same scaled coordinate system but with a sub-grid of an inputsub_size.
         """
