@@ -1,7 +1,7 @@
 from autoarray import numba_util
 import numpy as np
 
-from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoarray.structures.arrays.uniform_2d import Array2D
 
 from autoarray import exc
 from autoarray.mask import mask_2d_util
@@ -170,15 +170,15 @@ class Convolver:
 
         Parameters
         ----------
-        mask : Mask2D
+        mask
             The mask within which the convolved signal is calculated.
-        blurring_mask : Mask2D
+        blurring_mask
             A masks of pixels outside the masks but whose light blurs into it after PSF convolution.
         kernel : grid.PSF or ndarray
             An array representing a PSF.
         """
         if kernel.shape_native[0] % 2 == 0 or kernel.shape_native[1] % 2 == 0:
-            raise exc.ConvolverException("PSF kernel must be odd")
+            raise exc.KernelException("PSF kernel must be odd")
 
         self.mask = mask
 
@@ -321,7 +321,7 @@ class Convolver:
         """
 
         if self.blurring_mask is None:
-            raise exc.ConvolverException(
+            raise exc.KernelException(
                 "You cannot use the convolve_image function of a Convolver if the Convolver was"
                 "not created with a blurring_mask."
             )
@@ -401,6 +401,26 @@ class Convolver:
 
         return Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
 
+    def convolve_image_no_blurring_interpolation(self, image):
+        """For a given 1D array and blurring array, convolve the two using this convolver.
+
+        Parameters
+        -----------
+        image
+            1D array of the values which are to be blurred with the convolver's PSF.
+        blurring_image
+            1D array of the blurring values which blur into the array after PSF convolution.
+        """
+
+        convolved_image = self.convolve_no_blurring_jit(
+            image_1d_array=image,
+            image_frame_1d_indexes=self.image_frame_1d_indexes,
+            image_frame_1d_kernels=self.image_frame_1d_kernels,
+            image_frame_1d_lengths=self.image_frame_1d_lengths,
+        )
+
+        return Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
+
     @staticmethod
     @numba_util.jit()
     def convolve_no_blurring_jit(
