@@ -1,22 +1,70 @@
 from astropy import units
 import copy
 import numpy as np
-import pylops
-from pynufft.linalg.nufft_cpu import NUFFT_cpu
 import warnings
 
-from autoarray.structures.arrays.two_d.array_2d import Array2D
-from autoarray.structures.grids.two_d.grid_2d import Grid2D
+
+class NUFFTPlaceholder:
+    pass
+
+
+class PyLopsPlaceholder:
+    pass
+
+
+try:
+    from pynufft.linalg.nufft_cpu import NUFFT_cpu
+except ModuleNotFoundError:
+
+    NUFFT_cpu = NUFFTPlaceholder
+
+try:
+    import pylops
+
+    PyLopsOperator = pylops.LinearOperator
+except ModuleNotFoundError:
+
+    PyLopsOperator = PyLopsPlaceholder
+
+from autoarray.structures.arrays.uniform_2d import Array2D
+from autoarray.structures.grids.uniform_2d import Grid2D
 from autoarray.structures.visibilities import Visibilities
 
-from autoarray.structures.arrays.two_d import array_2d_util
+from autoarray.structures.arrays import array_2d_util
 from autoarray.operators import transformer_util
 
 
-class TransformerDFT(pylops.LinearOperator):
+def pynufft_exception():
+
+    raise ModuleNotFoundError(
+        "\n--------------------\n"
+        "You are attempting to perform interferometer analysis.\n\n"
+        "However, the optional library PyNUFFT (https://github.com/jyhmiinlin/pynufft) is not installed.\n\n"
+        "Install it via the command `pip install pynufft==2020.2.7`.\n\n"
+        "See ? for more information.\n"
+        "----------------------"
+    )
+
+
+def pylops_exception():
+
+    raise ModuleNotFoundError(
+        "\n--------------------\n"
+        "You are attempting to perform interferometer analysis.\n\n"
+        "However, the optional library PyLops (https://github.com/PyLops/pylops) is not installed.\n\n"
+        "Install it via the command `pip install pylops==1.11.1`.\n\n"
+        "See ? for more information.\n"
+        "----------------------"
+    )
+
+
+class TransformerDFT(PyLopsOperator):
     def __init__(self, uv_wavelengths, real_space_mask, preload_transform=True):
 
-        super(TransformerDFT, self).__init__()
+        if isinstance(self, PyLopsPlaceholder):
+            pylops_exception()
+
+        super().__init__()
 
         self.uv_wavelengths = uv_wavelengths.astype("float")
         self.real_space_mask = real_space_mask.mask_sub_1
@@ -46,6 +94,11 @@ class TransformerDFT(pylops.LinearOperator):
         self.dtype = "complex128"
         self.explicit = False
 
+        # NOTE: This is the scaling factor that needs to be applied to the adjoint operator
+        self.adjoint_scaling = (2.0 * self.grid.shape_native[0]) * (
+            2.0 * self.grid.shape_native[1]
+        )
+
     def visibilities_from(self, image):
 
         if self.preload_transform:
@@ -66,7 +119,7 @@ class TransformerDFT(pylops.LinearOperator):
 
         return Visibilities(visibilities=visibilities)
 
-    def image_from(self, visibilities):
+    def image_from(self, visibilities, use_adjoint_scaling: bool = False):
 
         image_slim = transformer_util.image_via_jit_from(
             n_pixels=self.grid.shape[0],
@@ -81,9 +134,7 @@ class TransformerDFT(pylops.LinearOperator):
             sub_size=self.real_space_mask.sub_size,
         )
 
-        return Array2D.manual_native(
-            array=image_native, pixel_scales=self.real_space_mask.pixel_scales
-        )
+        return Array2D.manual_mask(array=image_native, mask=self.real_space_mask)
 
     def transform_mapping_matrix(self, mapping_matrix):
 
@@ -104,9 +155,15 @@ class TransformerDFT(pylops.LinearOperator):
             )
 
 
-class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
+class TransformerNUFFT(NUFFT_cpu, PyLopsOperator):
     def __init__(self, uv_wavelengths, real_space_mask):
 
+        if isinstance(self, NUFFTPlaceholder):
+            pynufft_exception()
+
+        if isinstance(self, PyLopsPlaceholder):
+            pylops_exception()
+
         super(TransformerNUFFT, self).__init__()
 
         self.uv_wavelengths = uv_wavelengths
@@ -195,11 +252,15 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
             )  # flip due to PyNUFFT internal flip
         )
 
-    def image_from(self, visibilities):
-        image = np.real(self.adjoint(visibilities))
-        return Array2D.manual_native(
-            array=image, pixel_scales=self.real_space_mask.pixel_scales
-        )
+    def image_from(self, visibilities, use_adjoint_scaling: bool = False):
+
+        image = np.real(self.adjoint(visibilities))[::-1, :]
+
+        if use_adjoint_scaling:
+
+            image *= self.adjoint_scaling
+
+        return Array2D.manual_mask(array=image, mask=self.real_space_mask)
 
     def transform_mapping_matrix(self, mapping_matrix):
 
