@@ -4,15 +4,20 @@ set_backend()
 
 import matplotlib.pyplot as plt
 import numpy as np
-from typing import Optional, List, Union
+from typing import Iterable, Optional, List, Union
 
-from autoarray.structures.arrays.one_d.array_1d import Array1D
-from autoarray.structures.arrays.two_d.array_2d import Array2D
-from autoarray.inversion.mappers.rectangular import MapperRectangular
-from autoarray.inversion.mappers.voronoi import MapperVoronoi
+from autoconf import conf
+
+from autoarray.structures.arrays.uniform_1d import Array1D
+from autoarray.structures.arrays.uniform_2d import Array2D
+from autoarray.inversion.mappers.rectangular import MapperRectangularNoInterp
+from autoarray.inversion.mappers.delaunay import MapperDelaunay
+from autoarray.inversion.mappers.voronoi import MapperVoronoiNoInterp
 from autoarray.plot.mat_wrap.visuals import Visuals1D
 from autoarray.plot.mat_wrap.visuals import Visuals2D
 
+from autoarray.structures.arrays import array_2d_util
+
 from autoarray import exc
 from autoarray.plot.wrap import wrap_base as wb
 from autoarray.plot.wrap import wrap_1d as w1d
@@ -34,21 +39,21 @@ class AutoLabels:
 class AbstractMatPlot:
     def __init__(
         self,
-        units: wb.Units = wb.Units(),
-        figure: wb.Figure = wb.Figure(),
-        axis: wb.Axis = wb.Axis(),
-        cmap: wb.Cmap = wb.Cmap(),
-        colorbar: wb.Colorbar = wb.Colorbar(),
-        colorbar_tickparams: wb.ColorbarTickParams = wb.ColorbarTickParams(),
-        tickparams: wb.TickParams = wb.TickParams(),
-        yticks: wb.YTicks = wb.YTicks(),
-        xticks: wb.XTicks = wb.XTicks(),
-        title: wb.Title = wb.Title(),
-        ylabel: wb.YLabel = wb.YLabel(),
-        xlabel: wb.XLabel = wb.XLabel(),
-        text: wb.Text = wb.Text(),
-        legend: wb.Legend = wb.Legend(),
-        output: wb.Output = wb.Output(),
+        units: Optional[wb.Units] = None,
+        figure: Optional[wb.Figure] = None,
+        axis: Optional[wb.Axis] = None,
+        cmap: Optional[wb.Cmap] = None,
+        colorbar: Optional[wb.Colorbar] = None,
+        colorbar_tickparams: Optional[wb.ColorbarTickParams] = None,
+        tickparams: Optional[wb.TickParams] = None,
+        yticks: Optional[wb.YTicks] = None,
+        xticks: Optional[wb.XTicks] = None,
+        title: Optional[wb.Title] = None,
+        ylabel: Optional[wb.YLabel] = None,
+        xlabel: Optional[wb.XLabel] = None,
+        text: Optional[Union[wb.Text, List[wb.Text]]] = None,
+        legend: Optional[wb.Legend] = None,
+        output: Optional[wb.Output] = None,
     ):
         """
         Visualizes data structures (e.g an `Array2D`, `Grid2D`, `VectorField`, etc.) using Matplotlib.
@@ -64,7 +69,7 @@ class AbstractMatPlot:
         - `Line`: using `plt.plot`, `plt.semilogy`, `plt.loglog` or `plt.scatter`.
         - `VectorField`: using `plt.quiver`.
         - `RectangularMapper`: using `plt.imshow`.
-        - `VoronoiMapper`: using `plt.fill`.
+        - `MapperVoronoiNoInterp`: using `plt.fill`.
         
         Parameters
         ----------
@@ -103,21 +108,26 @@ class AbstractMatPlot:
             Sets if the figure is displayed on the user's screen or output to `.png` using `plt.show` and `plt.savefig`
         """
 
-        self.units = units
-        self.figure = figure
-        self.axis = axis
-        self.cmap = cmap
-        self.colorbar = colorbar
-        self.colorbar_tickparams = colorbar_tickparams
-        self.tickparams = tickparams
-        self.title = title
-        self.yticks = yticks
-        self.xticks = xticks
-        self.ylabel = ylabel
-        self.xlabel = xlabel
-        self.text = text
-        self.legend = legend
-        self.output = output
+        self.units = units or wb.Units()
+        self.figure = figure or wb.Figure()
+        self.axis = axis or wb.Axis()
+
+        self.cmap = cmap or wb.Cmap()
+
+        self.colorbar = colorbar or wb.Colorbar()
+        self.colorbar_tickparams = colorbar_tickparams or wb.ColorbarTickParams()
+
+        self.tickparams = tickparams or wb.TickParams()
+        self.yticks = yticks or wb.YTicks()
+        self.xticks = xticks or wb.XTicks()
+
+        self.title = title or wb.Title()
+        self.ylabel = ylabel or wb.YLabel()
+        self.xlabel = xlabel or wb.XLabel()
+
+        self.text = text or wb.Text()
+        self.legend = legend or wb.Legend()
+        self.output = output or wb.Output()
 
         self.number_subplots = None
         self.subplot_shape = None
@@ -195,25 +205,25 @@ class AbstractMatPlot:
 class MatPlot1D(AbstractMatPlot):
     def __init__(
         self,
-        units: wb.Units = wb.Units(),
-        figure: wb.Figure = wb.Figure(),
-        axis: wb.Axis = wb.Axis(),
-        cmap: wb.Cmap = wb.Cmap(),
-        colorbar: wb.Colorbar = wb.Colorbar(),
-        colorbar_tickparams: wb.ColorbarTickParams = wb.ColorbarTickParams(),
-        tickparams: wb.TickParams = wb.TickParams(),
-        yticks: wb.YTicks = wb.YTicks(),
-        xticks: wb.XTicks = wb.XTicks(),
-        title: wb.Title = wb.Title(),
-        ylabel: wb.YLabel = wb.YLabel(),
-        xlabel: wb.XLabel = wb.XLabel(),
-        text: wb.Text = wb.Text(),
-        legend: wb.Legend = wb.Legend(),
-        output: wb.Output = wb.Output(),
-        yx_plot: w1d.YXPlot = w1d.YXPlot(),
-        vertical_line_axvline: w1d.AXVLine = w1d.AXVLine(),
-        yx_scatter: w1d.YXPlot = w1d.YXScatter(),
-        fill_between: w1d.FillBetween = w1d.FillBetween(),
+        units: Optional[wb.Units] = None,
+        figure: Optional[wb.Figure] = None,
+        axis: Optional[wb.Axis] = None,
+        cmap: Optional[wb.Cmap] = None,
+        colorbar: Optional[wb.Colorbar] = None,
+        colorbar_tickparams: Optional[wb.ColorbarTickParams] = None,
+        tickparams: Optional[wb.TickParams] = None,
+        yticks: Optional[wb.YTicks] = None,
+        xticks: Optional[wb.XTicks] = None,
+        title: Optional[wb.Title] = None,
+        ylabel: Optional[wb.YLabel] = None,
+        xlabel: Optional[wb.XLabel] = None,
+        text: Optional[Union[wb.Text, List[wb.Text]]] = None,
+        legend: Optional[wb.Legend] = None,
+        output: Optional[wb.Output] = None,
+        yx_plot: Optional[w1d.YXPlot] = None,
+        vertical_line_axvline: Optional[w1d.AXVLine] = None,
+        yx_scatter: Optional[w1d.YXPlot] = None,
+        fill_between: Optional[w1d.FillBetween] = None,
     ):
         """
         Visualizes 1D data structures (e.g a `Line`, etc.) using Matplotlib.
@@ -285,10 +295,10 @@ class MatPlot1D(AbstractMatPlot):
             output=output,
         )
 
-        self.yx_plot = yx_plot
-        self.vertical_line_axvline = vertical_line_axvline
-        self.yx_scatter = yx_scatter
-        self.fill_between = fill_between
+        self.yx_plot = yx_plot or w1d.YXPlot()
+        self.vertical_line_axvline = vertical_line_axvline or w1d.AXVLine()
+        self.yx_scatter = yx_scatter or w1d.YXScatter()
+        self.fill_between = fill_between or w1d.FillBetween()
 
         self.is_for_multi_plot = False
         self.is_for_subplot = False
@@ -303,7 +313,7 @@ class MatPlot1D(AbstractMatPlot):
 
         Parameters
         ----------
-        is_for_subplot : bool
+        is_for_subplot
             The entry the `is_for_subplot` attribute of every `MatWrap` object is set too.
         """
         self.is_for_multi_plot = is_for_multi_plot
@@ -316,10 +326,10 @@ class MatPlot1D(AbstractMatPlot):
 
     def plot_yx(
         self,
-        y: Union[np.ndarray, List, Array1D],
+        y: Union[Array1D],
         visuals_1d: Visuals1D,
         auto_labels: AutoLabels,
-        x: Optional[Union[np.ndarray, List, Array1D]] = None,
+        x: Optional[Union[np.ndarray, Iterable, List, Array1D]] = None,
         plot_axis_type_override: Optional[str] = None,
         y_errors=None,
         x_errors=None,
@@ -343,6 +353,8 @@ class MatPlot1D(AbstractMatPlot):
         if x is None:
             x = np.arange(len(y))
             use_integers = True
+            pixel_scales = (x[1] - x[0],)
+            x = Array1D.manual_native(array=x, pixel_scales=pixel_scales)
 
         if self.yx_plot.plot_axis_type is None:
             plot_axis_type = "linear"
@@ -379,7 +391,7 @@ class MatPlot1D(AbstractMatPlot):
             plt.yscale("symlog")
 
         self.xticks.set(
-            array=None,
+            array=x,
             min_value=np.min(x),
             max_value=np.max(x),
             units=self.units,
@@ -390,7 +402,10 @@ class MatPlot1D(AbstractMatPlot):
         self.ylabel.set(units=self.units, auto_label=auto_labels.ylabel)
         self.xlabel.set(units=self.units, auto_label=auto_labels.xlabel)
 
-        self.text.set()
+        if not isinstance(self.text, list):
+            self.text.set()
+        else:
+            [text.set() for text in self.text]
 
         visuals_1d.plot_via_plotter(plotter=self)
 
@@ -405,37 +420,38 @@ class MatPlot1D(AbstractMatPlot):
 class MatPlot2D(AbstractMatPlot):
     def __init__(
         self,
-        units: wb.Units = wb.Units(),
-        figure: wb.Figure = wb.Figure(),
-        axis: wb.Axis = wb.Axis(),
-        cmap: wb.Cmap = wb.Cmap(),
-        colorbar: wb.Colorbar = wb.Colorbar(),
-        colorbar_tickparams: wb.ColorbarTickParams = wb.ColorbarTickParams(),
-        tickparams: wb.TickParams = wb.TickParams(),
-        yticks: wb.YTicks = wb.YTicks(),
-        xticks: wb.XTicks = wb.XTicks(),
-        title: wb.Title = wb.Title(),
-        ylabel: wb.YLabel = wb.YLabel(),
-        xlabel: wb.XLabel = wb.XLabel(),
-        legend: wb.Legend = wb.Legend(),
-        text: wb.Text = wb.Text(),
-        output: wb.Output = wb.Output(),
-        array_overlay: w2d.ArrayOverlay = w2d.ArrayOverlay(),
-        grid_scatter: w2d.GridScatter = w2d.GridScatter(),
-        grid_plot: w2d.GridPlot = w2d.GridPlot(),
-        grid_errorbar: w2d.GridErrorbar = w2d.GridErrorbar(),
-        vector_field_quiver: w2d.VectorFieldQuiver = w2d.VectorFieldQuiver(),
-        patch_overlay: w2d.PatchOverlay = w2d.PatchOverlay(),
-        voronoi_drawer: w2d.VoronoiDrawer = w2d.VoronoiDrawer(),
-        origin_scatter: w2d.OriginScatter = w2d.OriginScatter(),
-        mask_scatter: w2d.MaskScatter = w2d.MaskScatter(),
-        border_scatter: w2d.BorderScatter = w2d.BorderScatter(),
-        positions_scatter: w2d.PositionsScatter = w2d.PositionsScatter(),
-        index_scatter: w2d.IndexScatter = w2d.IndexScatter(),
-        pixelization_grid_scatter: w2d.PixelizationGridScatter = w2d.PixelizationGridScatter(),
-        parallel_overscan_plot: w2d.ParallelOverscanPlot = w2d.ParallelOverscanPlot(),
-        serial_prescan_plot: w2d.SerialPrescanPlot = w2d.SerialPrescanPlot(),
-        serial_overscan_plot: w2d.SerialOverscanPlot = w2d.SerialOverscanPlot(),
+        units: Optional[wb.Units] = None,
+        figure: Optional[wb.Figure] = None,
+        axis: Optional[wb.Axis] = None,
+        cmap: Optional[wb.Cmap] = None,
+        colorbar: Optional[wb.Colorbar] = None,
+        colorbar_tickparams: Optional[wb.ColorbarTickParams] = None,
+        tickparams: Optional[wb.TickParams] = None,
+        yticks: Optional[wb.YTicks] = None,
+        xticks: Optional[wb.XTicks] = None,
+        title: Optional[wb.Title] = None,
+        ylabel: Optional[wb.YLabel] = None,
+        xlabel: Optional[wb.XLabel] = None,
+        text: Optional[Union[wb.Text, List[wb.Text]]] = None,
+        legend: Optional[wb.Legend] = None,
+        output: Optional[wb.Output] = None,
+        array_overlay: Optional[w2d.ArrayOverlay] = None,
+        grid_scatter: Optional[w2d.GridScatter] = None,
+        grid_plot: Optional[w2d.GridPlot] = None,
+        grid_errorbar: Optional[w2d.GridErrorbar] = None,
+        vector_yx_quiver: Optional[w2d.VectorYXQuiver] = None,
+        patch_overlay: Optional[w2d.PatchOverlay] = None,
+        interpolated_reconstruction: Optional[w2d.InterpolatedReconstruction] = None,
+        voronoi_drawer: Optional[w2d.VoronoiDrawer] = None,
+        origin_scatter: Optional[w2d.OriginScatter] = None,
+        mask_scatter: Optional[w2d.MaskScatter] = None,
+        border_scatter: Optional[w2d.BorderScatter] = None,
+        positions_scatter: Optional[w2d.PositionsScatter] = None,
+        index_scatter: Optional[w2d.IndexScatter] = None,
+        pixelization_grid_scatter: Optional[w2d.PixelizationGridScatter] = None,
+        parallel_overscan_plot: Optional[w2d.ParallelOverscanPlot] = None,
+        serial_prescan_plot: Optional[w2d.SerialPrescanPlot] = None,
+        serial_overscan_plot: Optional[w2d.SerialOverscanPlot] = None,
     ):
         """
         Visualizes 2D data structures (e.g an `Array2D`, `Grid2D`, `VectorField`, etc.) using Matplotlib.
@@ -451,7 +467,7 @@ class MatPlot2D(AbstractMatPlot):
         - `Line`: using `plt.plot`, `plt.semilogy`, `plt.loglog` or `plt.scatter`.
         - `VectorField`: using `plt.quiver`.
         - `RectangularMapper`: using `plt.imshow`.
-        - `VoronoiMapper`: using `plt.fill`.
+        - `MapperVoronoiNoInterp`: using `plt.fill`.
 
         Parameters
         ----------
@@ -494,12 +510,14 @@ class MatPlot2D(AbstractMatPlot):
             Scatters a `Grid2D` of (y,x) coordinates over the figure using `plt.scatter`.
         grid_plot
             Plots lines of data (e.g. a y versus x plot via `plt.plot`, vertical lines via `plt.avxline`, etc.)
-        vector_field_quiver
+        vector_yx_quiver
             Plots a `VectorField` object using the matplotlib function `plt.quiver`.
         patch_overlay
             Overlays matplotlib `patches.Patch` objects over the figure, such as an `Ellipse`.
         voronoi_drawer
             Draws a colored Voronoi mesh of pixels using `plt.fill`.
+        interpolated_reconstruction
+            Draws a colored Delaunay mesh of pixels using `plt.fill`.
         origin_scatter
             Scatters the (y,x) origin of the data structure on the figure.
         mask_scatter
@@ -538,22 +556,34 @@ class MatPlot2D(AbstractMatPlot):
             output=output,
         )
 
-        self.origin_scatter = origin_scatter
-        self.mask_scatter = mask_scatter
-        self.border_scatter = border_scatter
-        self.grid_scatter = grid_scatter
-        self.grid_plot = grid_plot
-        self.grid_errorbar = grid_errorbar
-        self.positions_scatter = positions_scatter
-        self.index_scatter = index_scatter
-        self.pixelization_grid_scatter = pixelization_grid_scatter
-        self.vector_field_quiver = vector_field_quiver
-        self.patch_overlay = patch_overlay
-        self.array_overlay = array_overlay
-        self.voronoi_drawer = voronoi_drawer
-        self.parallel_overscan_plot = parallel_overscan_plot
-        self.serial_prescan_plot = serial_prescan_plot
-        self.serial_overscan_plot = serial_overscan_plot
+        self.array_overlay = array_overlay or w2d.ArrayOverlay()
+
+        self.grid_scatter = grid_scatter or w2d.GridScatter()
+        self.grid_plot = grid_plot or w2d.GridPlot()
+        self.grid_errorbar = grid_errorbar or w2d.GridErrorbar()
+
+        self.vector_yx_quiver = vector_yx_quiver or w2d.VectorYXQuiver()
+        self.patch_overlay = patch_overlay or w2d.PatchOverlay()
+
+        self.interpolated_reconstruction = (
+            interpolated_reconstruction or w2d.InterpolatedReconstruction()
+        )
+        self.voronoi_drawer = voronoi_drawer or w2d.VoronoiDrawer()
+
+        self.origin_scatter = origin_scatter or w2d.OriginScatter()
+        self.mask_scatter = mask_scatter or w2d.MaskScatter()
+        self.border_scatter = border_scatter or w2d.BorderScatter()
+        self.positions_scatter = positions_scatter or w2d.PositionsScatter()
+        self.index_scatter = index_scatter or w2d.IndexScatter()
+        self.pixelization_grid_scatter = (
+            pixelization_grid_scatter or w2d.PixelizationGridScatter()
+        )
+
+        self.parallel_overscan_plot = (
+            parallel_overscan_plot or w2d.ParallelOverscanPlot()
+        )
+        self.serial_prescan_plot = serial_prescan_plot or w2d.SerialPrescanPlot()
+        self.serial_overscan_plot = serial_overscan_plot or w2d.SerialOverscanPlot()
 
         self.is_for_subplot = False
 
@@ -595,7 +625,7 @@ class MatPlot2D(AbstractMatPlot):
         else:
             buffer = 1
 
-        if array.zoom_for_plot:
+        if conf.instance["visualize"]["general"]["general"]["zoom_around_mask"]:
 
             extent = array.extent_of_zoomed_array(buffer=buffer)
             array = array.zoomed_around_mask(buffer=buffer)
@@ -613,12 +643,15 @@ class MatPlot2D(AbstractMatPlot):
         aspect = self.figure.aspect_from(shape_native=array.shape_native)
         norm_scale = self.cmap.norm_from(array=array)
 
+        origin = conf.instance["visualize"]["general"]["general"]["imshow_origin"]
+
         plt.imshow(
             X=array.native,
             aspect=aspect,
-            cmap=self.cmap.config_dict["cmap"],
+            cmap=self.cmap.cmap,
             norm=norm_scale,
             extent=extent,
+            origin=origin,
         )
 
         if visuals_2d.array_overlay is not None:
@@ -642,6 +675,7 @@ class MatPlot2D(AbstractMatPlot):
             max_value=extent_axis[3],
             units=self.units,
         )
+
         self.xticks.set(
             array=array,
             min_value=extent_axis[0],
@@ -653,18 +687,18 @@ class MatPlot2D(AbstractMatPlot):
         self.ylabel.set(units=self.units, include_brackets=True)
         self.xlabel.set(units=self.units, include_brackets=True)
 
-        self.text.set()
+        if not isinstance(self.text, list):
+            self.text.set()
+        else:
+            [text.set() for text in self.text]
 
-        if self.colorbar is not None:
+        if self.colorbar is not False:
             cb = self.colorbar.set()
             self.colorbar_tickparams.set(cb=cb)
 
         grid_indexes = None
 
-        if (
-            visuals_2d.indexes is not None
-            or visuals_2d.pixelization_indexes is not None
-        ):
+        if visuals_2d.indexes is not None or visuals_2d.pix_indexes is not None:
             grid_indexes = array.mask.masked_grid
 
         visuals_2d.plot_via_plotter(plotter=self, grid_indexes=grid_indexes)
@@ -710,7 +744,7 @@ class MatPlot2D(AbstractMatPlot):
 
         elif color_array is not None:
 
-            cmap = plt.get_cmap(self.cmap.config_dict["cmap"])
+            cmap = plt.get_cmap(self.cmap.cmap)
 
             if y_errors is None and x_errors is None:
                 self.grid_scatter.scatter_grid_colored(
@@ -728,7 +762,7 @@ class MatPlot2D(AbstractMatPlot):
             if self.colorbar is not None:
 
                 colorbar = self.colorbar.set_with_color_values(
-                    cmap=self.cmap.config_dict["cmap"], color_values=color_array
+                    cmap=self.cmap.cmap, color_values=color_array
                 )
                 if colorbar is not None and self.colorbar_tickparams is not None:
                     self.colorbar_tickparams.set(cb=colorbar)
@@ -737,7 +771,10 @@ class MatPlot2D(AbstractMatPlot):
         self.ylabel.set(units=self.units, include_brackets=True)
         self.xlabel.set(units=self.units, include_brackets=True)
 
-        self.text.set()
+        if not isinstance(self.text, list):
+            self.text.set()
+        else:
+            [text.set() for text in self.text]
 
         extent = self.axis.config_dict.get("extent")
 
@@ -765,38 +802,67 @@ class MatPlot2D(AbstractMatPlot):
 
     def plot_mapper(
         self,
-        mapper: Union[MapperRectangular, MapperVoronoi],
+        mapper: Union[MapperRectangularNoInterp, MapperVoronoiNoInterp],
         visuals_2d: Visuals2D,
         auto_labels: AutoLabels,
+        interpolate_to_uniform: bool = True,
         source_pixelilzation_values=None,
     ):
 
-        if isinstance(mapper, MapperRectangular):
+        if isinstance(mapper, MapperRectangularNoInterp):
 
             self._plot_rectangular_mapper(
                 mapper=mapper,
                 visuals_2d=visuals_2d,
                 auto_labels=auto_labels,
+                interpolate_to_uniform=interpolate_to_uniform,
                 source_pixelilzation_values=source_pixelilzation_values,
             )
 
+        elif isinstance(mapper, MapperDelaunay):
+            self._plot_delaunay_mapper(
+                mapper=mapper,
+                visuals_2d=visuals_2d,
+                auto_labels=auto_labels,
+                interpolate_to_uniform=interpolate_to_uniform,
+                source_pixelilzation_values=source_pixelilzation_values,
+            )
         else:
 
             self._plot_voronoi_mapper(
                 mapper=mapper,
                 visuals_2d=visuals_2d,
                 auto_labels=auto_labels,
+                interpolate_to_uniform=interpolate_to_uniform,
                 source_pixelilzation_values=source_pixelilzation_values,
             )
 
     def _plot_rectangular_mapper(
         self,
-        mapper: MapperRectangular,
+        mapper: MapperRectangularNoInterp,
         visuals_2d: Visuals2D,
         auto_labels: AutoLabels,
+        interpolate_to_uniform: bool = True,
         source_pixelilzation_values=None,
     ):
 
+        if source_pixelilzation_values is not None:
+
+            solution_array_2d = array_2d_util.array_2d_native_from(
+                array_2d_slim=source_pixelilzation_values,
+                mask_2d=np.full(
+                    fill_value=False, shape=mapper.source_pixelization_grid.shape_native
+                ),
+                sub_size=1,
+            )
+
+            source_pixelilzation_values = Array2D.manual(
+                array=solution_array_2d,
+                sub_size=1,
+                pixel_scales=mapper.source_pixelization_grid.pixel_scales,
+                origin=mapper.source_pixelization_grid.origin,
+            )
+
         extent = self.axis.config_dict.get("extent")
         extent = (
             extent if extent is not None else mapper.source_pixelization_grid.extent
@@ -826,7 +892,10 @@ class MatPlot2D(AbstractMatPlot):
             array=None, min_value=extent[0], max_value=extent[1], units=self.units
         )
 
-        self.text.set()
+        if not isinstance(self.text, list):
+            self.text.set()
+        else:
+            [text.set() for text in self.text]
 
         self.grid_plot.plot_rectangular_grid_lines(
             extent=mapper.source_pixelization_grid.extent,
@@ -846,11 +915,69 @@ class MatPlot2D(AbstractMatPlot):
             self.output.to_figure(structure=None, auto_filename=auto_labels.filename)
             self.figure.close()
 
-    def _plot_voronoi_mapper(
+    def _plot_delaunay_mapper(
         self,
-        mapper: MapperVoronoi,
+        mapper: MapperDelaunay,
         visuals_2d: Visuals2D,
         auto_labels: AutoLabels,
+        interpolate_to_uniform: bool = True,
+        source_pixelilzation_values=None,
+    ):
+
+        extent = self.axis.config_dict.get("extent")
+        extent = (
+            extent if extent is not None else mapper.source_pixelization_grid.extent
+        )
+
+        aspect_inv = self.figure.aspect_for_subplot_from(extent=extent)
+
+        if not self.is_for_subplot:
+            self.figure.open()
+        else:
+            self.setup_subplot(aspect=aspect_inv)
+
+        self.axis.set(extent=extent, grid=mapper.source_pixelization_grid)
+
+        self.tickparams.set()
+        self.yticks.set(
+            array=None, min_value=extent[2], max_value=extent[3], units=self.units
+        )
+        self.xticks.set(
+            array=None, min_value=extent[0], max_value=extent[1], units=self.units
+        )
+
+        if not isinstance(self.text, list):
+            self.text.set()
+        else:
+            [text.set() for text in self.text]
+
+        self.interpolated_reconstruction.imshow_reconstruction(
+            mapper=mapper,
+            pixel_values=source_pixelilzation_values,
+            cmap=self.cmap,
+            colorbar=self.colorbar,
+            colorbar_tickparams=self.colorbar_tickparams,
+            aspect=aspect_inv,
+        )
+
+        self.title.set(auto_title=auto_labels.title)
+        self.ylabel.set(units=self.units, include_brackets=True)
+        self.xlabel.set(units=self.units, include_brackets=True)
+
+        visuals_2d.plot_via_plotter(
+            plotter=self, grid_indexes=mapper.source_grid_slim, mapper=mapper
+        )
+
+        if not self.is_for_subplot:
+            self.output.to_figure(structure=None, auto_filename=auto_labels.filename)
+            self.figure.close()
+
+    def _plot_voronoi_mapper(
+        self,
+        mapper: MapperVoronoiNoInterp,
+        visuals_2d: Visuals2D,
+        auto_labels: AutoLabels,
+        interpolate_to_uniform: bool = True,
         source_pixelilzation_values=None,
     ):
 
@@ -878,16 +1005,31 @@ class MatPlot2D(AbstractMatPlot):
             array=None, min_value=extent[0], max_value=extent[1], units=self.units
         )
 
-        self.text.set()
+        if not isinstance(self.text, list):
+            self.text.set()
+        else:
+            [text.set() for text in self.text]
 
-        self.voronoi_drawer.draw_voronoi_pixels(
-            mapper=mapper,
-            values=source_pixelilzation_values,
-            cmap=self.cmap,
-            colorbar=self.colorbar,
-            colorbar_tickparams=self.colorbar_tickparams,
-        )
+        if not interpolate_to_uniform:
 
+            self.voronoi_drawer.draw_voronoi_pixels(
+                mapper=mapper,
+                pixel_values=source_pixelilzation_values,
+                cmap=self.cmap,
+                colorbar=self.colorbar,
+                colorbar_tickparams=self.colorbar_tickparams,
+            )
+
+        else:
+
+            self.interpolated_reconstruction.imshow_reconstruction(
+                mapper=mapper,
+                pixel_values=source_pixelilzation_values,
+                cmap=self.cmap,
+                colorbar=self.colorbar,
+                colorbar_tickparams=self.colorbar_tickparams,
+                aspect=aspect_inv,
+            )
         self.title.set(auto_title=auto_labels.title)
         self.ylabel.set(units=self.units, include_brackets=True)
         self.xlabel.set(units=self.units, include_brackets=True)
