@@ -3,16 +3,14 @@ from matplotlib import patches as ptch
 import numpy as np
 from typing import List, Optional, Union
 
-from autoarray.structures.arrays.one_d.array_1d import Array1D
-from autoarray.structures.grids.one_d.grid_1d import Grid1D
-from autoarray.structures.arrays.two_d.array_2d import Array2D
-from autoarray.structures.grids.two_d.grid_2d import Grid2D
-from autoarray.structures.grids.two_d.grid_2d_irregular import Grid2DIrregular
+from autoarray.structures.arrays.uniform_1d import Array1D
+from autoarray.structures.grids.uniform_1d import Grid1D
+from autoarray.structures.arrays.uniform_2d import Array2D
+from autoarray.structures.grids.uniform_2d import Grid2D
+from autoarray.structures.grids.irregular_2d import Grid2DIrregular
 from autoarray.mask.mask_1d import Mask1D
 from autoarray.mask.mask_2d import Mask2D
-from autoarray.structures.vector_fields.vector_field_irregular import (
-    VectorField2DIrregular,
-)
+from autoarray.structures.vectors.irregular import VectorYX2DIrregular
 from autoarray.plot.mat_wrap.include import Include1D
 
 
@@ -106,21 +104,21 @@ class Visuals1D(AbstractVisuals):
 class Visuals2D(AbstractVisuals):
     def __init__(
         self,
-        origin: Grid2D = None,
-        mask: Mask2D = None,
-        border: Grid2D = None,
-        lines: List[Array1D] = None,
-        positions: Union[Grid2DIrregular, List[Grid2DIrregular]] = None,
-        grid: Grid2D = None,
-        pixelization_grid: Grid2D = None,
-        vector_field: VectorField2DIrregular = None,
-        patches: List[ptch.Patch] = None,
-        array_overlay: Array2D = None,
+        origin: Optional[Grid2D] = None,
+        mask: Optional[Mask2D] = None,
+        border: Optional[Grid2D] = None,
+        lines: Optional[List[Array1D]] = None,
+        positions: Optional[Union[Grid2DIrregular, List[Grid2DIrregular]]] = None,
+        grid: Optional[Grid2D] = None,
+        pixelization_grid: Optional[Grid2D] = None,
+        vectors: Optional[VectorYX2DIrregular] = None,
+        patches: Optional[List[ptch.Patch]] = None,
+        array_overlay: Optional[Array2D] = None,
         parallel_overscan=None,
         serial_prescan=None,
         serial_overscan=None,
         indexes=None,
-        pixelization_indexes=None,
+        pix_indexes=None,
     ):
 
         self.origin = origin
@@ -130,14 +128,14 @@ class Visuals2D(AbstractVisuals):
         self.positions = positions
         self.grid = grid
         self.pixelization_grid = pixelization_grid
-        self.vector_field = vector_field
+        self.vectors = vectors
         self.patches = patches
         self.array_overlay = array_overlay
         self.parallel_overscan = parallel_overscan
         self.serial_prescan = serial_prescan
         self.serial_overscan = serial_overscan
         self.indexes = indexes
-        self.pixelization_indexes = pixelization_indexes
+        self.pix_indexes = pix_indexes
 
     def plot_via_plotter(self, plotter, grid_indexes=None, mapper=None):
 
@@ -159,10 +157,8 @@ class Visuals2D(AbstractVisuals):
         if self.positions is not None:
             plotter.positions_scatter.scatter_grid(grid=self.positions)
 
-        if self.vector_field is not None:
-            plotter.vector_field_quiver.quiver_vector_field(
-                vector_field=self.vector_field
-            )
+        if self.vectors is not None:
+            plotter.vector_yx_quiver.quiver_vectors(vectors=self.vectors)
 
         if self.patches is not None:
             plotter.patch_overlay.overlay_patches(patches=self.patches)
@@ -175,10 +171,9 @@ class Visuals2D(AbstractVisuals):
                 grid=grid_indexes, indexes=self.indexes
             )
 
-        if self.pixelization_indexes is not None and mapper is not None:
-            indexes = mapper.pixelization_indexes_for_slim_indexes(
-                pixelization_indexes=self.pixelization_indexes
-            )
+        if self.pix_indexes is not None and mapper is not None:
+
+            indexes = mapper.pix_indexes_for_slim_indexes(pix_indexes=self.pix_indexes)
 
             plotter.index_scatter.scatter_grid_indexes(
                 grid=mapper.source_grid_slim, indexes=indexes
