@@ -20,7 +20,7 @@ from .wrap_2d import (
     ArrayOverlay,
     GridScatter,
     GridPlot,
-    VectorFieldQuiver,
+    VectorYXQuiver,
     PatchOverlay,
     VoronoiDrawer,
     OriginScatter,
