@@ -12,12 +12,13 @@ from typing import List, Union, Optional, Tuple
 from autoarray.plot.wrap import wrap_base as wb
 
 from autoarray.plot.wrap.wrap_base import AbstractMatWrap
+from autoarray.inversion.mappers.voronoi import MapperVoronoiNoInterp
 from autoarray.inversion.mappers.voronoi import MapperVoronoi
-from autoarray.structures.grids.two_d.grid_2d import Grid2D
-from autoarray.structures.grids.two_d.grid_2d_irregular import Grid2DIrregular
-from autoarray.structures.vector_fields.vector_field_irregular import (
-    VectorField2DIrregular,
-)
+from autoarray.inversion.mappers.delaunay import MapperDelaunay
+from autoarray.inversion.pixelizations import pixelization_util
+from autoarray.structures.grids.uniform_2d import Grid2D
+from autoarray.structures.grids.irregular_2d import Grid2DIrregular
+from autoarray.structures.vectors.irregular import VectorYX2DIrregular
 
 from autoarray import exc
 
@@ -144,7 +145,7 @@ class GridScatter(AbstractMatWrap2D):
             The grid of (y,x) coordinates that is plotted.
         color_array : ndarray
             The array of RGB color values used to color the grid.
-        cmap : str
+        cmap
             The Matplotlib colormap used for the grid point coloring.
         """
 
@@ -390,8 +391,8 @@ class GridErrorbar(AbstractMatWrap2D):
                 plt.errorbar(
                     y=grid[:, 0],
                     x=grid[:, 1],
-                    yerr=y_errors,
-                    xerr=x_errors,
+                    yerr=np.asarray(y_errors),
+                    xerr=np.asarray(x_errors),
                     c=next(color),
                     **config_dict,
                 )
@@ -417,7 +418,7 @@ class GridErrorbar(AbstractMatWrap2D):
             The grid of (y,x) coordinates that is plotted.
         color_array : ndarray
             The array of RGB color values used to color the grid.
-        cmap : str
+        cmap
             The Matplotlib colormap used for the grid point coloring.
         """
 
@@ -429,14 +430,14 @@ class GridErrorbar(AbstractMatWrap2D):
         plt.errorbar(
             y=grid[:, 0],
             x=grid[:, 1],
-            yerr=y_errors,
-            xerr=x_errors,
+            yerr=np.asarray(y_errors),
+            xerr=np.asarray(x_errors),
             zorder=0.0,
             **self.config_dict,
         )
 
 
-class VectorFieldQuiver(AbstractMatWrap2D):
+class VectorYXQuiver(AbstractMatWrap2D):
     """
     Plots a `VectorField` data structure. A vector field is a set of 2D vectors on a grid of 2d (y,x) coordinates.
     These are plotted as arrows representing the (y,x) components of each vector at each (y,x) coordinate of it
@@ -447,21 +448,21 @@ class VectorFieldQuiver(AbstractMatWrap2D):
     https://matplotlib.org/3.3.2/api/_as_gen/matplotlib.pyplot.quiver.html
     """
 
-    def quiver_vector_field(self, vector_field: VectorField2DIrregular):
+    def quiver_vectors(self, vectors: VectorYX2DIrregular):
         """
          Plot a vector field using the matplotlib method `plt.quiver` such that each vector appears as an arrow whose
          direction depends on the y and x magnitudes of the vector.
 
          Parameters
          ----------
-         vector_field : VectorField2DIrregular
+         vectors : VectorYX2DIrregular
              The vector field that is plotted using `plt.quiver`.
          """
         plt.quiver(
-            vector_field.grid[:, 1],
-            vector_field.grid[:, 0],
-            vector_field[:, 1],
-            vector_field[:, 0],
+            vectors.grid[:, 1],
+            vectors.grid[:, 0],
+            vectors[:, 1],
+            vectors[:, 0],
             **self.config_dict,
         )
 
@@ -488,14 +489,13 @@ class PatchOverlay(AbstractMatWrap2D):
             The patches that are laid over the figure.
         """
 
-        patch_collection = PatchCollection(patches=patches, **self.config_dict)
-
-        plt.gcf().gca().add_collection(patch_collection)
+        # patch_collection = PatchCollection(patches=patches, **self.config_dict)
+        # plt.gcf().gca().add_collection(patch_collection)
 
 
 class VoronoiDrawer(AbstractMatWrap2D):
     """
-    Draws Voronoi pixels from a `MapperVoronoi` object (see `inversions.mapper`). This includes both drawing
+    Draws Voronoi pixels from a `MapperVoronoiNoInterp` object (see `inversions.mapper`). This includes both drawing
     each Voronoi cell and coloring it according to a color value.
 
     The mapper contains the grid of (y,x) coordinate where the centre of each Voronoi cell is plotted.
@@ -507,11 +507,11 @@ class VoronoiDrawer(AbstractMatWrap2D):
 
     def draw_voronoi_pixels(
         self,
-        mapper: MapperVoronoi,
-        values: np.ndarray,
-        cmap: wb.Cmap,
-        colorbar: wb.Colorbar,
-        colorbar_tickparams: wb.ColorbarTickParams = None,
+        mapper: MapperVoronoiNoInterp,
+        pixel_values: Optional[np.ndarray],
+        cmap: Optional[wb.Cmap],
+        colorbar: Optional[wb.Colorbar],
+        colorbar_tickparams: Optional[wb.ColorbarTickParams] = None,
     ):
         """
         Draws the Voronoi pixels of the input `mapper` using its `pixelization_grid` which contains the (y,x) 
@@ -519,39 +519,42 @@ class VoronoiDrawer(AbstractMatWrap2D):
         
         Parameters
         ----------
-        mapper : MapperVoronoi
-            An object which contains the (y,x) grid of Voronoi cell centres.
-        values
+        mapper
+            A mapper object which contains the Voronoi mesh.
+        pixel_values
             An array used to compute the color values that every Voronoi cell is plotted using.
-        cmap : str
+        cmap
             The colormap used to plot each Voronoi cell.
-        colorbar : Colorbar
+        colorbar
             The `Colorbar` object in `mat_base` used to set the colorbar of the figure the Voronoi mesh is plotted on.
         """
-        regions, vertices = self.voronoi_polygons(voronoi=mapper.voronoi)
+        regions, vertices = pixelization_util.voronoi_revised_from(
+            voronoi=mapper.voronoi
+        )
 
-        if values is not None:
+        if pixel_values is not None:
 
-            vmin = cmap.vmin_from(array=values)
-            vmax = cmap.vmax_from(array=values)
+            vmin = cmap.vmin_from(array=pixel_values)
+            vmax = cmap.vmax_from(array=pixel_values)
 
-            color_values = np.where(values > vmax, vmax, values)
-            color_values = np.where(values < vmin, vmin, color_values)
+            color_values = np.where(pixel_values > vmax, vmax, pixel_values)
+            color_values = np.where(pixel_values < vmin, vmin, color_values)
 
             if vmax != vmin:
                 color_array = (color_values - vmin) / (vmax - vmin)
             else:
                 color_array = np.ones(color_values.shape[0])
 
-            cmap = plt.get_cmap(cmap.config_dict["cmap"])
+            cmap = plt.get_cmap(cmap.cmap)
 
             if colorbar is not None:
 
-                colorbar = colorbar.set_with_color_values(
+                cb = colorbar.set_with_color_values(
                     cmap=cmap, color_values=color_values
                 )
-                if colorbar is not None and colorbar_tickparams is not None:
-                    colorbar_tickparams.set(cb=colorbar)
+
+                if cb is not None and colorbar_tickparams is not None:
+                    colorbar_tickparams.set(cb=cb)
 
         else:
             cmap = plt.get_cmap("Greys")
@@ -559,89 +562,98 @@ class VoronoiDrawer(AbstractMatWrap2D):
 
         for region, index in zip(regions, range(mapper.pixels)):
             polygon = vertices[region]
-            col = cmap(color_array[index])
-            plt.fill(*zip(*polygon), facecolor=col, zorder=-1, **self.config_dict)
+            color = cmap(color_array[index])
 
-    def voronoi_polygons(self, voronoi, radius=None):
+            plt.fill(*zip(*polygon), facecolor=color, zorder=-1, **self.config_dict)
+
+
+class InterpolatedReconstruction(AbstractMatWrap2D):
+    """
+    Given a `Mapper` and a corresponding array of `pixel_values` (e.g. the reconstruction values of a Delaunay
+    triangulation) plot the values using `plt.imshow()`.
+
+    The `pixel_values` are an ndarray of values which correspond to the irregular pixels of the pixelization (e.g. for
+    a Delaunay triangulation they are the connecting corners of each triangle or Voronoi mesh). This cannot be plotted
+    with `imshow()`, therefore this class first converts the `pixel_values` from this irregular grid to a uniform 2D
+    array of square pixels via interpolation.
+
+    The interpolation routine depends on the `Mapper`, with most mappers having their own built-in interpolation
+    routine specific to that pixelization.
+
+    This object wraps methods described in below:
+
+    - plt.imshow: https://matplotlib.org/3.3.2/api/_as_gen/matplotlib.pyplot.imshow.html
+    """
+
+    def imshow_reconstruction(
+        self,
+        mapper: Union[MapperDelaunay, MapperVoronoiNoInterp, MapperVoronoi],
+        pixel_values: np.ndarray,
+        cmap: wb.Cmap,
+        colorbar: wb.Colorbar,
+        colorbar_tickparams: wb.ColorbarTickParams = None,
+        aspect=None,
+    ):
         """
-        Reconstruct infinite voronoi regions in a 2D diagram to finite regions.
+        Given a `Mapper` and a corresponding array of `pixel_values` (e.g. the reconstruction values of a Delaunay
+        triangulation) plot the values using `plt.imshow()`.
 
+        The `pixel_values` are an ndarray of values which correspond to the irregular pixels of the pixelization (e.g. for
+        a Delaunay triangulation they are the connecting corners of each triangle or Voronoi mesh). This cannot be plotted
+        with `imshow()`, therefore this class first converts the `pixel_values` from this irregular grid to a uniform 2D
+        array of square pixels via interpolation.
+
+        The interpolation routine depends on the `Mapper`, with most mappers having their own built-in interpolation
+        routine specific to that pixelization.
+
+        This object wraps methods described in below:
+
+        - plt.imshow: https://matplotlib.org/3.3.2/api/_as_gen/matplotlib.pyplot.imshow.html
+        
         Parameters
         ----------
-        voronoi : Voronoi
-            The input Voronoi diagram that is being plotted.
-        radius, optional
-            Distance to 'points at infinity'.
-
-        Returns
-        -------
-        regions : list of tuples
-            Indices of vertices in each revised Voronoi regions.
-        vertices : list of tuples
-            Grid2DIrregular for revised Voronoi vertices. Same as coordinates
-            of input vertices, with 'points at infinity' appended to the
-            end.
+        mapper
+            An object which contains a 2D grid of pixelization pixels (e.g. Voronoi mesh cells) and defines how to
+            interpolate values from the pixelization.
+        pixel_values
+            The pixel values of the pixelization (e.g. a Voronoi mesh) which are interpolated to a uniform square
+            array for plotting with `imshow()`.
+        cmap
+            The colormap used by `imshow()` to plot the pixelization values.
+        colorbar
+            The `Colorbar` object in `mat_base` used to set the colorbar of the figure the interpolated pixelization
+            values (e.g. values interpolated from the Voronoi mesh) are plotted on.
+        colorbar_tickparams
+            Controls the tick parameters of the colorbar.
         """
 
-        if voronoi.points.shape[1] != 2:
-            raise ValueError("Requires 2D input")
+        if pixel_values is None:
+            return
 
-        new_regions = []
-        new_vertices = voronoi.vertices.tolist()
+        vmin = cmap.vmin_from(array=pixel_values)
+        vmax = cmap.vmax_from(array=pixel_values)
 
-        center = voronoi.points.mean(axis=0)
-        if radius is None:
-            radius = voronoi.points.ptp().max() * 2
+        color_values = np.where(pixel_values > vmax, vmax, pixel_values)
+        color_values = np.where(pixel_values < vmin, vmin, color_values)
 
-        # Construct a map containing all ridges for a given point
-        all_ridges = {}
-        for (p1, p2), (v1, v2) in zip(voronoi.ridge_points, voronoi.ridge_vertices):
-            all_ridges.setdefault(p1, []).append((p2, v1, v2))
-            all_ridges.setdefault(p2, []).append((p1, v1, v2))
+        cmap = plt.get_cmap(cmap.cmap)
 
-        # Reconstruct infinite regions
-        for p1, region in enumerate(voronoi.point_region):
-            vertices = voronoi.regions[region]
+        if colorbar is not None:
 
-            if all(v >= 0 for v in vertices):
-                # finite region
-                new_regions.append(vertices)
-                continue
+            colorbar = colorbar.set_with_color_values(
+                cmap=cmap, color_values=color_values
+            )
+            if colorbar is not None and colorbar_tickparams is not None:
+                colorbar_tickparams.set(cb=colorbar)
 
-            # reconstruct a non-finite region
-            ridges = all_ridges[p1]
-            new_region = [v for v in vertices if v >= 0]
+        interpolation_array = mapper.interpolated_array_from(values=pixel_values)
 
-            for p2, v1, v2 in ridges:
-                if v2 < 0:
-                    v1, v2 = v2, v1
-                if v1 >= 0:
-                    # finite ridge: already in the region
-                    continue
-
-                # Compute the missing endpoint of an infinite ridge
-
-                t = voronoi.points[p2] - voronoi.points[p1]  # tangent
-                t /= np.linalg.norm(t)
-                n = np.array([-t[1], t[0]])  # hyper
-
-                midpoint = voronoi.points[[p1, p2]].mean(axis=0)
-                direction = np.sign(np.dot(midpoint - center, n)) * n
-                far_point = voronoi.vertices[v2] + direction * radius
-
-                new_region.append(len(new_vertices))
-                new_vertices.append(far_point.tolist())
-
-            # sort region counterclockwise
-            vs = np.asarray([new_vertices[v] for v in new_region])
-            c = vs.mean(axis=0)
-            angles = np.arctan2(vs[:, 1] - c[1], vs[:, 0] - c[0])
-            new_region = np.array(new_region)[np.argsort(angles)]
-
-            # finish
-            new_regions.append(new_region.tolist())
-
-        return new_regions, np.asarray(new_vertices)
+        plt.imshow(
+            X=interpolation_array.native,
+            cmap=cmap,
+            extent=mapper.source_pixelization_grid.extent_square,
+            aspect=aspect,
+        )
 
 
 class OriginScatter(GridScatter):
