@@ -1,7 +1,8 @@
-from autoconf import conf
 import matplotlib
+import pickle
 
-from autoarray.structures.arrays.two_d.array_2d import Array2D
+from autoconf import conf
+from autoarray.structures.arrays.uniform_2d import Array2D
 
 from typing import Union, List, Optional, Tuple
 
@@ -25,21 +26,23 @@ def set_backend():
 import matplotlib.pyplot as plt
 import matplotlib.colors as colors
 import matplotlib.cm as cm
+from matplotlib.ticker import FormatStrFormatter
+
 import numpy as np
 from os import path
 import os
 
 
-from autoarray.structures.abstract_structure import AbstractStructure
+from autoarray.structures.abstract_structure import Structure
 from autoarray import exc
 
 
 class Units:
     def __init__(
         self,
-        use_scaled: bool = None,
-        conversion_factor: float = None,
-        in_kpc: bool = None,
+        use_scaled: Optional[bool] = None,
+        conversion_factor: Optional[float] = None,
+        in_kpc: Optional[bool] = None,
     ):
         """
         This object controls the units of a plotted figure, and performs multiple tasks when making the plot:
@@ -75,7 +78,7 @@ class Units:
             self.use_scaled = use_scaled
         else:
             try:
-                self.use_scaled = conf.instance["visualize"]["general"]["general"][
+                self.use_scaled = conf.instance["visualize"]["general"]["units"][
                     "use_scaled"
                 ]
             except:
@@ -343,6 +346,9 @@ class Cmap(AbstractMatWrap):
         vmin = self.vmin_from(array=array)
         vmax = self.vmax_from(array=array)
 
+        if isinstance(self.config_dict["norm"], colors.Normalize):
+            return self.config_dict["norm"]
+
         if self.config_dict["norm"] in "linear":
             return colors.Normalize(vmin=vmin, vmax=vmax)
         elif self.config_dict["norm"] in "log":
@@ -364,6 +370,18 @@ class Cmap(AbstractMatWrap):
                 "{linear, log, symmetric_log}"
             )
 
+    @property
+    def cmap(self):
+
+        if self.config_dict["cmap"] == "default":
+
+            directory = path.dirname(path.realpath(__file__))
+
+            with open(path.join(directory, f"cmap.pkl"), "rb") as f:
+                return pickle.load(f)
+
+        return self.config_dict["cmap"]
+
 
 class Colorbar(AbstractMatWrap):
     def __init__(
@@ -436,7 +454,7 @@ class Colorbar(AbstractMatWrap):
         cax.set_array(color_values)
 
         if self.manual_tick_values is None and self.manual_tick_labels is None:
-            plt.colorbar(mappable=cax, **self.config_dict)
+            cb = plt.colorbar(mappable=cax, **self.config_dict)
         elif (
             self.manual_tick_values is not None and self.manual_tick_labels is not None
         ):
@@ -445,6 +463,8 @@ class Colorbar(AbstractMatWrap):
             )
             cb.ax.set_yticklabels(self.manual_tick_labels)
 
+        return cb
+
 
 class ColorbarTickParams(AbstractMatWrap):
     """
@@ -475,7 +495,12 @@ class TickParams(AbstractMatWrap):
 
 
 class AbstractTicks(AbstractMatWrap):
-    def __init__(self, manual_values: Optional[List[float]] = None, **kwargs):
+    def __init__(
+        self,
+        manual_values: Optional[List[float]] = None,
+        manual_units: Optional[str] = None,
+        **kwargs,
+    ):
         """
         The settings used to customize a figure's y and x ticks using the `YTicks` and `XTicks` objects.
 
@@ -492,6 +517,7 @@ class AbstractTicks(AbstractMatWrap):
         super().__init__(**kwargs)
 
         self.manual_values = manual_values
+        self.manual_units = manual_units
 
     def tick_values_from(self, min_value: float, max_value: float) -> np.ndarray:
         """
@@ -505,12 +531,18 @@ class AbstractTicks(AbstractMatWrap):
         max_value
             the maximum value of the ticks that figure is plotted using.
         """
+
         if self.manual_values is not None:
-            return np.linspace(min_value, max_value, len(self.manual_values))
+            return self.manual_values
         return np.linspace(min_value, max_value, 5)
 
     def tick_values_in_units_from(
-        self, array: Array2D, min_value: float, max_value: float, units: Units
+        self,
+        array: Array2D,
+        min_value: float,
+        max_value: float,
+        units: Units,
+        axis: int,
     ) -> Optional[np.ndarray]:
         """
         Calculate the labels used for the yticks or xticks from input values of the minimum and maximum coordinate
@@ -529,12 +561,24 @@ class AbstractTicks(AbstractMatWrap):
             the maximum value of the ticks that figure is plotted using.
         units
             The units the tick values are plotted using.
+        axis
+            Whether to use the y or x axis to estimate the tick labels.
         """
 
         if self.manual_values is not None:
             return np.asarray(self.manual_values)
         elif not units.use_scaled:
-            return np.linspace(0, array.shape_native[0], 5).astype("int")
+            try:
+                return np.linspace(0, array.shape_native[axis], 5).astype("int")
+            except IndexError:
+                return np.linspace(0, array.shape_native[0], 5).astype("int")
+            except AttributeError:
+                try:
+                    return np.linspace(0, np.asarray(array).shape[axis], 5).astype(
+                        "int"
+                    )
+                except IndexError:
+                    return np.linspace(0, np.asarray(array).shape[0], 5).astype("int")
         elif (units.use_scaled and units.conversion_factor is None) or not units.in_kpc:
             return np.round(np.linspace(min_value, max_value, 5), 2)
         elif units.use_scaled and units.conversion_factor is not None:
@@ -574,10 +618,18 @@ class YTicks(AbstractTicks):
 
         ticks = self.tick_values_from(min_value=min_value, max_value=max_value)
         labels = self.tick_values_in_units_from(
-            array=array, min_value=min_value, max_value=max_value, units=units
+            array=array, min_value=min_value, max_value=max_value, units=units, axis=0
         )
         plt.yticks(ticks=ticks, labels=labels, **self.config_dict)
 
+        if self.manual_units is not None:
+            plt.gca().yaxis.set_major_formatter(
+                FormatStrFormatter(f"{self.manual_units}")
+            )
+
+        if not units.use_scaled:
+            plt.gca().invert_yaxis()
+
 
 class XTicks(AbstractTicks):
     def set(
@@ -610,11 +662,22 @@ class XTicks(AbstractTicks):
         else:
 
             ticks = self.tick_values_from(min_value=min_value, max_value=max_value)
+
             labels = self.tick_values_in_units_from(
-                array=array, min_value=min_value, max_value=max_value, units=units
+                array=array,
+                min_value=min_value,
+                max_value=max_value,
+                units=units,
+                axis=1,
             )
+
         plt.xticks(ticks=ticks, labels=labels, **self.config_dict)
 
+        if self.manual_units is not None:
+            plt.gca().xaxis.set_major_formatter(
+                FormatStrFormatter(f"{self.manual_units}")
+            )
+
 
 class Title(AbstractMatWrap):
     def __init__(self, **kwargs):
@@ -698,7 +761,7 @@ class AbstractLabel(AbstractMatWrap):
         if units is None:
             return None
 
-        if units.in_kpc is not None:
+        if units.in_kpc is not None and units.use_scaled:
             if units.in_kpc:
                 return "kpc"
             else:
@@ -706,8 +769,7 @@ class AbstractLabel(AbstractMatWrap):
 
         if units.use_scaled:
             return "scaled"
-        else:
-            return "pixels"
+        return "pixels"
 
 
 class YLabel(AbstractLabel):
@@ -815,7 +877,10 @@ class Output:
         self,
         path: Optional[str] = None,
         filename: Optional[str] = None,
+        prefix: Optional[str] = None,
+        suffix: Optional[str] = None,
         format: Union[str, List[str]] = None,
+        format_folder: bool = False,
         bypass: bool = False,
     ):
         """
@@ -835,22 +900,29 @@ class Output:
             If the figure is output to hard-disk the path of the folder it is saved to.
         filename
             If the figure is output to hard-disk the filename used to save it.
+        prefix
+            A prefix appended before the file name, e.g. ("prefix_filename").
+        prefix
+            A prefix appended after the file name, e.g. ("filenam_suffix").
         format
             The format of the output, 'show' displays on the computer screen, 'png' outputs to .png, 'fits' outputs to
             `.fits` format.
+        format_folder
+            If `True`, all images are output in a folder giving the format name, for
+            example `path/to/output/png/filename.png`. This can make managing large image catalogues easier.
         bypass
             Whether to bypass the `plt.show` or `plt.savefig` methods, used when plotting a subplot.
         """
         self.path = path
 
         if path is not None and path:
-            try:
-                os.makedirs(path)
-            except FileExistsError:
-                pass
+            os.makedirs(path, exist_ok=True)
 
         self.filename = filename
+        self.prefix = prefix
+        self.suffix = suffix
         self._format = format
+        self.format_folder = format_folder
         self.bypass = bypass
 
     @property
@@ -865,10 +937,34 @@ class Output:
             return [self.format]
         return self.format
 
+    def output_path_from(self, format):
+
+        if format in "show":
+            return None
+
+        if self.format_folder:
+            output_path = path.join(self.path, format)
+        else:
+            output_path = self.path
+
+        os.makedirs(output_path, exist_ok=True)
+
+        return output_path
+
+    def filename_from(self, auto_filename):
+
+        filename = auto_filename if self.filename is None else self.filename
+
+        if self.prefix is not None:
+            filename = f"{self.prefix}{filename}"
+
+        if self.suffix is not None:
+            filename = f"{filename}{self.suffix}"
+
+        return filename
+
     def to_figure(
-        self,
-        structure: Optional[AbstractStructure],
-        auto_filename: Optional[str] = None,
+        self, structure: Optional[Structure], auto_filename: Optional[str] = None
     ):
         """
         Output the figure, by either displaying it on the user's screen or to the hard-disk as a .png or .fits file.
@@ -877,41 +973,52 @@ class Output:
         ----------
         structure
             The 2D array of image to be output, required for outputting the image as a fits file.
+        auto_filename
+            If the filename is not manually specified this name is used instead, which is defined in the parent plotter.
         """
 
-        filename = auto_filename if self.filename is None else self.filename
+        filename = self.filename_from(auto_filename=auto_filename)
 
         for format in self.format_list:
 
+            output_path = self.output_path_from(format=format)
+
             if not self.bypass:
                 if format == "show":
                     plt.show()
                 elif format == "png":
-                    plt.savefig(path.join(self.path, f"{filename}.png"))
+                    plt.savefig(path.join(output_path, f"{filename}.png"))
                 elif format == "pdf":
-                    plt.savefig(path.join(self.path, f"{filename}.pdf"))
+                    plt.savefig(path.join(output_path, f"{filename}.pdf"))
                 elif format == "fits":
                     if structure is not None:
                         structure.output_to_fits(
-                            file_path=path.join(self.path, f"{filename}.fits"),
+                            file_path=path.join(output_path, f"{filename}.fits"),
                             overwrite=True,
                         )
 
-    def subplot_to_figure(self, auto_filename=None):
+    def subplot_to_figure(self, auto_filename: Optional[str] = None):
         """
         Output a subplot figure, either as an image on the screen or to the hard-disk as a png or fits file.
+
+        Parameters
+        ----------
+        auto_filename
+            If the filename is not manually specified this name is used instead, which is defined in the parent plotter.
         """
 
-        filename = auto_filename if self.filename is None else self.filename
+        filename = self.filename_from(auto_filename=auto_filename)
 
         for format in self.format_list:
 
+            output_path = self.output_path_from(format=format)
+
             if format == "show":
                 plt.show()
             elif format == "png":
-                plt.savefig(path.join(self.path, f"{filename}.png"))
+                plt.savefig(path.join(output_path, f"{filename}.png"))
             elif format == "pdf":
-                plt.savefig(path.join(self.path, f"{filename}.pdf"))
+                plt.savefig(path.join(output_path, f"{filename}.pdf"))
 
 
 def remove_spaces_and_commas_from(colors):
