@@ -2,16 +2,16 @@ from autoarray import numba_util as numba
 from autoarray.geometry import geometry_util as geometry
 from autoarray.mask import mask_1d_util as mask_1d
 from autoarray.mask import mask_2d_util as mask_2d
-from autoarray.structures.arrays.one_d import array_1d_util as array_1d
-from autoarray.structures.arrays.two_d import array_2d_util as array_2d
-from autoarray.structures.grids.one_d import grid_1d_util as grid_1d
-from autoarray.structures.grids.two_d import grid_2d_util as grid_2d
-from autoarray.structures.grids.two_d import sparse_util as sparse
+from autoarray.structures.arrays import array_1d_util as array_1d
+from autoarray.structures.arrays import array_2d_util as array_2d
+from autoarray.structures.grids import grid_1d_util as grid_1d
+from autoarray.structures.grids import grid_2d_util as grid_2d
+from autoarray.structures.grids import sparse_2d_util as sparse
 from autoarray.layout import layout_util as layout
 from autoarray.fit import fit_util as fit
 from autoarray.inversion.pixelizations import pixelization_util as pixelization
 from autoarray.inversion.mappers import mapper_util as mapper
 from autoarray.inversion.regularization import regularization_util as regularization
-from autoarray.inversion.linear_eqn import linear_eqn_util as linear_eqn
+from autoarray.inversion.linear_eqn import leq_util as leq
 from autoarray.inversion.inversion import inversion_util as inversion
 from autoarray.operators import transformer_util as transformer
